@@ -184,6 +184,32 @@ class SecurityValueHolder(object):
         return SecurityShiftedValueHolder(self, n)
 
 
+class RankedSecurityValueHolder(SecurityValueHolder):
+
+    def __init__(self, innerValue):
+        if isinstance(innerValue, SecurityValueHolder):
+            self._inner = copy.deepcopy(innerValue)
+        else:
+            # TODO: make the rank value holder workable for a symbol
+            raise ValueError("Currently only value holder input is allowed for rank holder.")
+        self._window = self._inner.window
+        self._returnSize = self._inner.valueSize
+        self._dependency = self._inner.dependency
+        self._symbolList = self._inner.symbolList
+
+    @property
+    def value(self):
+        raw_values = self._inner.value
+        return raw_values.rank()
+
+    @property
+    def holders(self):
+        return self._inner.holders
+
+    def push(self, data):
+        self._inner.push(data)
+
+
 class FilteredSecurityValueHolder(SecurityValueHolder):
     def __init__(self, computer, filtering):
         self._filter = copy.deepcopy(filtering)
@@ -191,7 +217,9 @@ class FilteredSecurityValueHolder(SecurityValueHolder):
         self._window = max(computer.window, filtering.window)
         self._returnSize = computer.valueSize
         self._dependency = _merge2set(
-            self._computer._dependency, self._filter._dependency)
+            self._computer._dependency,
+            self._filter._dependency
+        )
         self._symbolList = computer.symbolList
         self._updated = False
         self._cachedFlag = None
@@ -219,16 +247,7 @@ class FilteredSecurityValueHolder(SecurityValueHolder):
                 return np.nan
         except KeyError:
 
-            if isinstance(item, tuple):
-                symbolList = set(i.lower() for i in item).intersection(
-                    set(filter_flags.index))  # to be corrected
-                pyFinAssert(len(symbolList) == len(item), ValueError,
-                            "security name can't be duplicated")
-                res = SecuritiesValues(
-                    {s: self.holders[s].result() for s in symbolList}
-                )
-                return res
-            elif isinstance(item, SecurityValueHolder):
+            if isinstance(item, SecurityValueHolder):
                 return FilteredSecurityValueHolder(self, item)
             else:
                 raise TypeError("{0} is not a valid id".format(item))
