@@ -14,6 +14,10 @@ from PyFin.Math.Accumulators.IAccumulators import Accumulator
 from PyFin.Math.Accumulators.StatelessAccumulators import Latest
 from PyFin.Math.Accumulators.StatelessAccumulators import Positive
 from PyFin.Math.Accumulators.StatelessAccumulators import Negative
+from PyFin.Math.Accumulators.StatelessAccumulators import XAverage
+from PyFin.Math.Accumulators.StatelessAccumulators import StatelessAccumulator
+from PyFin.Math.Accumulators.IAccumulators import Pow
+from PyFin.Math.Accumulators.IAccumulators import Identity
 from PyFin.Utilities import pyFinAssert
 from PyFin.Utilities import isClose
 
@@ -293,6 +297,10 @@ class MovingVariance(SingleValuedValueHolder):
 
     def result(self):
         length = self.size
+
+        if length == 0:
+            return np.nan
+
         tmp = self._runningSumSquare - self._runningSum * self._runningSum / length
 
         if self._isPop:
@@ -301,7 +309,7 @@ class MovingVariance(SingleValuedValueHolder):
             if length >= 2:
                 return tmp / (length - 1)
             else:
-                raise ZeroDivisionError("Container has too few samples: {0:d}".format(self.size))
+                return np.nan
 
 
 class MovingNegativeVariance(SingleValuedValueHolder):
@@ -333,14 +341,14 @@ class MovingNegativeVariance(SingleValuedValueHolder):
                 tmp = self._runningNegativeSumSquare - self._runningNegativeSum * self._runningNegativeSum / length
                 return tmp / length
             else:
-                raise ZeroDivisionError("Negative population variance container has less than 1 samples")
+                return np.nan
         else:
             if self._runningNegativeCount >= 2:
                 length = self._runningNegativeCount
                 tmp = self._runningNegativeSumSquare - self._runningNegativeSum * self._runningNegativeSum / length
                 return tmp / (length - 1)
             else:
-                raise ZeroDivisionError("Negative sample variance container has less than 2 samples")
+                return np.nan
 
 
 class MovingCountedPositive(SingleValuedValueHolder):
@@ -390,8 +398,12 @@ class MovingHistoricalWindow(StatefulValueHolder):
 
     def push(self, data):
         value = super(MovingHistoricalWindow, self).push(data)
-        if np.isnan(value):
-            return np.nan
+        try:
+            if np.isnan(value):
+                return np.nan
+        except TypeError:
+            if not value:
+                return np.nan
         _ = self._dumpOneValue(value)
 
     def __getitem__(self, item):
@@ -451,7 +463,7 @@ class MovingCorrelation(StatefulValueHolder):
             else:
                 return 0.0
         else:
-            raise ZeroDivisionError("Container has less than 2 samples")
+            return np.nan
 
 
 # Calculator for several series
@@ -490,4 +502,132 @@ class MovingCorrelationMatrix(StatefulValueHolder):
             denominator = np.sqrt(denominator * denominator.T)
             return nominator / denominator
         else:
-            raise ZeroDivisionError("Container has less than 2 samples")
+            return np.ones(len(self._runningSum)) * np.nan
+
+
+class MovingProduct(SingleValuedValueHolder):
+    def __init__(self, window, dependency='x'):
+        super(MovingProduct, self).__init__(window, dependency)
+        self._runningProduct = np.nan
+    def push(self, data):
+        value = super(MovingProduct, self).push(data)
+        if np.isnan(value):
+            return np.nan
+        self._dumpOneValue(value)
+        if all(self._con):
+            self._runningProduct = np.product(self._con)
+        else:
+            self._runningProduct = 0
+    def result(self):
+        return self._runningProduct
+
+
+
+class MovingCenterMoment(SingleValuedValueHolder):
+    def __init__(self, window, order, dependency='x'):
+        super(MovingCenterMoment, self).__init__(window, dependency)
+        self._order = order
+
+    def push(self, data):
+        value = super(MovingCenterMoment, self).push(data)
+        self._dumpOneValue(value)
+        if np.isnan(value):
+            return np.nan
+        else:
+            self._runningMoment = np.mean(np.power(np.abs(np.array(self._con) - np.mean(self._con)), self._order))
+
+    def result(self):
+        return self._runningMoment
+
+
+class MovingSkewness(SingleValuedValueHolder):
+    def __init__(self, window, dependency='x'):
+        super(MovingSkewness, self).__init__(window,dependency)
+        self._runningStd3 = Pow(MovingVariance(window, dependency, isPopulation=True), 1.5)
+        self._runningMoment3 = MovingCenterMoment(window, 3, dependency)
+        self._runningSkewness = self._runningMoment3 / self._runningStd3
+
+    def push(self, data):
+        self._runningSkewness.push(data)
+
+    def result(self):
+        return self._runningSkewness.result()
+
+
+
+class MovingTsMaxPos(SortedValueHolder):
+    def __init__(self, window, dependency='x'):
+        super(MovingTsMaxPos, self).__init__(window, dependency)
+        self._runningTsMaxPos = np.nan
+
+    def push(self, data):
+        super(MovingTsMaxPos,self).push(data)
+        self._max = self._sortedArray[-1]
+        self._runningTsMaxPos = self._con.index(self._max)
+
+    def result(self):
+        return self._runningTsMaxPos
+
+
+class MovingTsMinPos(SortedValueHolder):
+    def __init__(self, window, dependency='x'):
+        super(MovingTsMinPos,self).__init__(window, dependency)
+        self._runningTsMinPos = np.nan
+
+    def push(self, data):
+        value = super(MovingTsMinPos,self).push(data)
+        self._min = self._sortedArray[0]
+        self._runningTsMinPos = self._con.index(self._min)
+
+    def result(self):
+        return self._runningTsMinPos
+
+
+class MovingKurtosis(SingleValuedValueHolder):
+    def __init__(self, window, dependency='x'):
+        super(MovingKurtosis, self).__init__(window, dependency)
+        self._runningStd4 = Pow(MovingVariance(window, dependency, isPopulation=True), 2)
+        self._runningMoment4 = MovingCenterMoment(window, 4, dependency)
+        self._runningKurtosis = self._runningMoment4 / self._runningStd4
+
+    def push(self, data):
+        self._runningKurtosis.push(data)
+
+    def result(self):
+        return self._runningKurtosis.result()
+
+
+class MovingRSV(SingleValuedValueHolder):
+    def __init__(self, window, dependency='x'):
+        super(MovingRSV, self).__init__(window, dependency)
+        self._runningMax = MovingMax(window, dependency)
+        self._runningMin = MovingMinimum(window, dependency)
+
+    def push(self, data):
+        self._runningMax.push(data)
+        self._runningMin.push(data)
+        value = super(MovingRSV, self).push(data)
+        if np.isnan(value):
+            return np.nan
+        else:
+            self._runningRSV = (Identity(value) - self._runningMin) / (self._runningMax - self._runningMin)
+
+    def result(self):
+        return self._runningRSV.result()
+
+
+
+class MACD(StatelessAccumulator):
+    def __init__(self, short, long, dependency='x', method=XAverage):
+        super(MACD, self).__init__(dependency)
+        self._short_average = method(window=short, dependency=dependency)
+        self._long_average = method(window=long, dependency=dependency)
+
+    def push(self, data):
+        self._short_average.push(data)
+        self._long_average.push(data)
+        if self._isFull == 0 and self._short_average.isFull and self._long_average.isFull:
+            self._isFull = 1
+
+    def result(self):
+        return self._short_average.result() - self._long_average.result()
\ No newline at end of file
