@@ -8,6 +8,7 @@ Created on 2015-7-25
 import math
 import numpy as np
 from PyFin.Math.Accumulators.IAccumulators import Accumulator
+from PyFin.Math.Accumulators.IAccumulators import Pow
 
 
 def _checkParameterList(dependency):
@@ -46,8 +47,12 @@ class Latest(StatelessAccumulator):
 
     def push(self, data):
         value = super(Latest, self).push(data)
-        if np.isnan(value):
-            return np.nan
+        try:
+            if np.isnan(value):
+                return np.nan
+        except TypeError:
+            if not value:
+                return np.nan
         self._latest = value
 
     def result(self):
@@ -274,22 +279,6 @@ class XAverage(StatelessAccumulator):
         return self._average
 
 
-class MACD(StatelessAccumulator):
-    def __init__(self, short, long, dependency='x'):
-        super(MACD, self).__init__(dependency)
-        self._short_average = XAverage(window=short, dependency=dependency)
-        self._long_average = XAverage(window=long, dependency=dependency)
-
-    def push(self, data):
-        self._short_average.push(data)
-        self._long_average.push(data)
-        if self._isFull == 0 and self._short_average.isFull and self._long_average.isFull:
-            self._isFull = 1
-
-    def result(self):
-        return self._short_average.result() - self._long_average.result()
-
-
 class Variance(StatelessAccumulator):
     def __init__(self, dependency='x', isPopulation=False):
         super(Variance, self).__init__(dependency)
@@ -313,9 +302,9 @@ class Variance(StatelessAccumulator):
 
         pop_num = self._currentCount if self._isPop else self._currentCount - 1
 
-        try:
+        if pop_num:
             return tmp / pop_num
-        except ZeroDivisionError:
+        else:
             return np.nan
 
 
@@ -342,12 +331,75 @@ class Correlation(StatelessAccumulator):
         self._currentCount += 1
 
     def result(self):
-        try:
-            n = self._currentCount
-            nominator = n * self._runningSumCrossSquare - self._runningSumLeft * self._runningSumRight
-            denominator = (n * self._runningSumSquareLeft - self._runningSumLeft * self._runningSumLeft) \
-                          * (n * self._runningSumSquareRight - self._runningSumRight * self._runningSumRight)
-            denominator = math.sqrt(denominator)
+        n = self._currentCount
+        nominator = n * self._runningSumCrossSquare - self._runningSumLeft * self._runningSumRight
+        denominator = (n * self._runningSumSquareLeft - self._runningSumLeft * self._runningSumLeft) \
+                      * (n * self._runningSumSquareRight - self._runningSumRight * self._runningSumRight)
+        denominator = math.sqrt(denominator)
+        if denominator != 0:
             return nominator / denominator
-        except ZeroDivisionError:
+        else:
+            return np.nan
+
+
+class Product(StatelessAccumulator):
+    def __init__(self, dependency='x'):
+        super(Product,self).__init__(dependency)
+        self._product = 1.0
+
+    def push(self, data):
+        value = super(Product, self).push(data)
+        try:
+            if np.isnan(value):
                 return np.nan
+        except TypeError:
+            if not value:
+                return np.nan
+        self._product *= value
+
+    def result(self):
+        return self._product
+
+
+class CenterMoment(StatelessAccumulator):
+    def __init__(self, order, dependency='x'):
+        super(CenterMoment, self).__init__(dependency)
+        self._this_list = []
+        self._order = order
+
+    def push(self, data):
+        value = super(CenterMoment, self).push(data)
+        if np.isnan(value):
+            return np.nan
+        else:
+            self._this_list.append(value)
+            self._moment = np.mean(np.power(np.abs(np.array(self._this_list) - np.mean(self._this_list)), self._order))
+
+    def result(self):
+        return self._moment
+
+
+class Skewness(StatelessAccumulator):
+    def __init__(self, dependency='x'):
+        super(Skewness, self).__init__(dependency)
+        self._std3 = Pow(Variance(dependency, isPopulation=True), 1.5)
+        self._moment3 = CenterMoment(3, dependency)
+        self._skewness = self._moment3 / self._std3
+    def push(self,data):
+        self._skewness.push(data)
+    def result(self):
+        return self._skewness.result()
+
+
+class Kurtosis(StatelessAccumulator):
+    def __init__(self, dependency='x'):
+        super(Kurtosis, self).__init__(dependency)
+        self._std4 = Pow(Variance(dependency, isPopulation=True), 2)
+        self._moment4 = CenterMoment(4, dependency)
+        self._kurtosis = self._moment4 / self._std4
+
+    def push(self, data):
+        self._kurtosis.push(data)
+
+    def result(self):
+        return self._kurtosis.result()
\ No newline at end of file
