@@ -27,7 +27,15 @@ from PyFin.Math.Accumulators import MovingNegativeVariance
 from PyFin.Math.Accumulators import MovingHistoricalWindow
 from PyFin.Math.Accumulators import MovingCorrelation
 from PyFin.Math.Accumulators import MovingCorrelationMatrix
-
+from PyFin.Math.Accumulators import MovingProduct
+from PyFin.Math.Accumulators import MovingCenterMoment
+from PyFin.Math.Accumulators import MovingSkewness
+from PyFin.Math.Accumulators import MovingTsMaxPos
+from PyFin.Math.Accumulators import MovingTsMinPos
+from PyFin.Math.Accumulators import MovingKurtosis
+from PyFin.Math.Accumulators import MovingRSV
+from PyFin.Math.Accumulators import MACD
+from PyFin.Math.Accumulators import XAverage
 
 class TestStatefulAccumulators(unittest.TestCase):
     def setUp(self):
@@ -350,8 +358,7 @@ class TestStatefulAccumulators(unittest.TestCase):
             runningSumSquare += value * value
 
             if i == 0:
-                with self.assertRaises(ArithmeticError):
-                    mv.result()
+                self.assertTrue(np.isnan(mv.result()))
 
             if i >= window:
                 runningSum -= con[0]
@@ -372,15 +379,13 @@ class TestStatefulAccumulators(unittest.TestCase):
         mv = MovingNegativeVariance(20, dependency='z', isPopulation=True)
         mv.push(dict(z=20.))
 
-        with self.assertRaises(ArithmeticError):
-            _ = mv.result()
+        self.assertTrue(np.isnan(mv.result()))
 
         mv = MovingNegativeVariance(20, dependency='z', isPopulation=False)
         mv.push(dict(z=20.))
         mv.push(dict(z=-20.))
 
-        with self.assertRaises(ArithmeticError):
-            _ = mv.result()
+        self.assertTrue(np.isnan(mv.result()))
 
         dirName = os.path.dirname(os.path.abspath(__file__))
         filePath = os.path.join(dirName, 'data/negativevariance.csv')
@@ -396,8 +401,7 @@ class TestStatefulAccumulators(unittest.TestCase):
                 mv.push(dict(z=float(row[1])))
 
                 if mv._runningNegativeCount == 1:
-                    with self.assertRaises(ArithmeticError):
-                        mv.result()
+                    self.assertTrue(np.isnan(mv.result()))
 
                 if i >= window:
                     expected = float(row[6])
@@ -462,8 +466,7 @@ class TestStatefulAccumulators(unittest.TestCase):
                 mv.push(dict(z=float(row[0]), t=float(row[1])))
 
                 if i == 1:
-                    with self.assertRaises(ArithmeticError):
-                        _ = mv.result()
+                    self.assertTrue(np.isnan(mv.result()))
 
                 if i >= window:
                     expected = float(row[2])
@@ -501,8 +504,7 @@ class TestStatefulAccumulators(unittest.TestCase):
                 row = [float(value) for value in row]
                 mv.push(dict(samples=row))
                 if i == 0:
-                    with self.assertRaises(ArithmeticError):
-                        _ = mv.result()
+                    self.assertTrue(np.all(np.isnan(mv.result())))
                 if (i + 1) == window:
                     calculated = mv.result()
                     for k, row in enumerate(first100Sample):
@@ -519,3 +521,204 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                    "Last 100 sample correlation matrix different at ({0:d}, {1:d})\n"
                                                    "Expected: {2:f}\n"
                                                    "Calculated: {3:f}".format(k, j, corr, calculated[k][j]))
+
+
+
+    def testMovingProduct(self):
+        window = 10
+        mp = MovingProduct(window, dependency='x')
+
+        con = []
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            mp.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                expected = np.product(con)
+                calculated = mp.result()
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "product expected:   {1:f}\n"
+                                                                "product calculated: {2:f}".format(i, expected,
+                                                                                                       calculated))
+
+
+    def testMovingCenterMoment(self):
+        window = 10
+        order = 1
+        mm = MovingCenterMoment(window, order, dependency='x')
+
+        con = []
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            mm.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                expected = np.mean(np.power(np.abs(np.array(con) - np.mean(con)), order))
+                calculated = mm.result()
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "moment expected:   {1:f}\n"
+                                                                "moment calculated: {2:f}".format(i, expected,
+                                                                                                  calculated))
+
+
+        window = 10
+        order = 2
+        mm = MovingCenterMoment(window, order, dependency='x')
+
+        con = []
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            mm.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                expected = np.mean(np.power(np.abs(np.array(con) - np.mean(con)), order))
+                calculated = mm.result()
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "moment expected:   {1:f}\n"
+                                                                "moment calculated: {2:f}".format(i, expected,
+                                                                                                  calculated))
+
+
+    def testMovingSkewness(self):
+        window = 10
+        ms = MovingSkewness(window, dependency='x')
+
+        con = []
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            ms.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = ms.result()
+                this_moment3 = np.mean(np.power(np.abs(np.array(con) - np.mean(con)), 3))
+                expected = this_moment3 / np.power(np.std(con), 3)
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "skewness expected:   {1:f}\n"
+                                                                "skewness calculated: {2:f}".format(i, expected,
+                                                                                                  calculated))
+
+
+    def testMovingTsMaxPos(self):
+        window = 10
+        maxPos = MovingTsMaxPos(window, dependency='x')
+
+        con = []
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            maxPos.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = maxPos.result()
+                expected = con.index(np.max(con))
+                self.assertEqual(expected, calculated, "at index {0:d}\n"
+                                                        "maxPos expected:   {1:f}\n"
+                                                        "maxPos calculated: {2:f}".format(i, expected,
+                                                                                              calculated))
+
+
+    def testMovingTsMinPos(self):
+        window = 10
+        minPos = MovingTsMinPos(window, dependency='x')
+
+        con = []
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            minPos.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = minPos.result()
+                expected = con.index(np.min(con))
+                self.assertEqual(expected, calculated, "at index {0:d}\n"
+                                                       "minPos expected:   {1:f}\n"
+                                                       "minPos calculated: {2:f}".format(i, expected,
+                                                                                         calculated))
+
+
+    def testMovingKurtosis(self):
+        window = 10
+        mk = MovingKurtosis(window, dependency='x')
+
+        con = []
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            mk.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = mk.result()
+                this_moment4 = np.mean(np.power(np.abs(np.array(con) - np.mean(con)), 4))
+                expected = this_moment4 / np.power(np.std(con), 4)
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "kurtosis expected:   {1:f}\n"
+                                                                "kurtosis calculated: {2:f}".format(i, expected,
+                                                                                                    calculated))
+
+
+    def testMovingRSV(self):
+        window = 10
+        rsv = MovingRSV(window, dependency='x')
+
+        con = []
+        for i, value in enumerate(self.sample):
+            con.append(value)
+            rsv.push(dict(x=value))
+            if i >= window:
+                con = con[1:]
+            if i >= window - 1:
+                calculated = rsv.result()
+                expected = (value - np.min(con)) / (np.max(con) - np.min(con))
+                self.assertAlmostEqual(expected, calculated, 8, "at index {0:d}\n"
+                                                                "rsv expected:   {1:f}\n"
+                                                                "rsv calculated: {2:f}".format(i, expected,
+                                                                                               calculated))
+
+
+    def testMACD(self):
+        macd = MACD(short=5, long=10, dependency='close')
+        short_average = XAverage(window=5, dependency='close')
+        long_average = XAverage(window=10, dependency='close')
+
+        for i, value in enumerate(self.sample):
+            macd.push(dict(close=value))
+            short_average.push(dict(close=value))
+            long_average.push(dict(close=value))
+            expected = short_average.result() - long_average.result()
+
+            calculated = macd.result()
+            self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
+                                                             "expected x-average:   {1:f}\n"
+                                                             "calculated x-average: {2:f}".format(i,
+                                                                                                  expected,
+                                                                                                  calculated))
+
+
+    def testEMAMACD(self):
+        fast = 5
+        slow = 10
+        ema_window = 10
+        macd = MACD(fast, slow, 'close')
+        ema_macd = XAverage(ema_window, macd)
+
+        macd_diff = macd - ema_macd
+
+        for i, value in enumerate(self.sample):
+            macd.push(dict(close=value))
+            ema_macd.push(dict(close=value))
+            macd_diff.push(dict(close=value))
+            expected = macd.value - ema_macd.value
+            calculated = macd_diff.value
+            self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
+                                                             "expected ema macd diff:   {1:f}\n"
+                                                             "calculated ema macd diff: {2:f}".format(i, expected, calculated))
+
+
+
+if __name__ == '__main__':
+    unittest.main()
+
