@@ -10,7 +10,6 @@ import math
 import numpy as np
 from PyFin.Math.Accumulators.StatelessAccumulators import Average
 from PyFin.Math.Accumulators.StatelessAccumulators import XAverage
-from PyFin.Math.Accumulators.StatelessAccumulators import MACD
 from PyFin.Math.Accumulators.StatelessAccumulators import Max
 from PyFin.Math.Accumulators.StatelessAccumulators import Minimum
 from PyFin.Math.Accumulators.StatelessAccumulators import Diff
@@ -19,6 +18,10 @@ from PyFin.Math.Accumulators.StatelessAccumulators import LogReturn
 from PyFin.Math.Accumulators.StatelessAccumulators import Sum
 from PyFin.Math.Accumulators.StatelessAccumulators import Variance
 from PyFin.Math.Accumulators.StatelessAccumulators import Correlation
+from PyFin.Math.Accumulators.StatelessAccumulators import Product
+from PyFin.Math.Accumulators.StatelessAccumulators import CenterMoment
+from PyFin.Math.Accumulators.StatelessAccumulators import Skewness
+from PyFin.Math.Accumulators.StatelessAccumulators import Kurtosis
 
 
 class TestStatelessAccumulators(unittest.TestCase):
@@ -59,43 +62,6 @@ class TestStatelessAccumulators(unittest.TestCase):
                                                                                                   expected,
                                                                                                   calculated))
 
-    def testMACD(self):
-        macd = MACD(short=5, long=10, dependency='close')
-        short_average = XAverage(window=5, dependency='close')
-        long_average = XAverage(window=10, dependency='close')
-
-        for i, value in enumerate(self.samplesClose):
-            macd.push(dict(close=value))
-            short_average.push(dict(close=value))
-            long_average.push(dict(close=value))
-            expected = short_average.result() - long_average.result()
-
-            calculated = macd.result()
-            self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
-                                                             "expected x-average:   {1:f}\n"
-                                                             "calculated x-average: {2:f}".format(i,
-                                                                                                  expected,
-                                                                                                  calculated))
-
-    def testEMAMACD(self):
-        fast = 5
-        slow = 10
-        ema_window = 10
-        macd = MACD(fast, slow, 'close')
-        ema_macd = XAverage(ema_window, macd)
-
-        macd_diff = macd - ema_macd
-
-        for i, value in enumerate(self.samplesClose):
-            macd.push(dict(close=value))
-            ema_macd.push(dict(close=value))
-            macd_diff.push(dict(close=value))
-            expected = macd.value - ema_macd.value
-            calculated = macd_diff.value
-            self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
-                                                             "expected ema macd diff:   {1:f}\n"
-                                                             "calculated ema macd diff: {2:f}".format(i, expected, calculated))
-
     def testMax(self):
         mm = Max(dependency='close')
 
@@ -222,3 +188,95 @@ class TestStatelessAccumulators(unittest.TestCase):
                                                                  "expected correlation:   {1:f}\n"
                                                                  "calculated correlation: {2:f}".format(i, expected,
                                                                                                         calculated))
+
+    def testProduct(self):
+        product = Product(dependency='close')
+        expected = 1
+        for i, value in enumerate(self.samplesClose):
+            product.push(dict(close=value))
+            calculated = product.result()
+            expected *= value
+            self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
+                                                             "expected product:   {1:f}\n"
+                                                             "calculated product: {2:f}".format(i, expected,
+                                                                                                calculated))
+
+    def testCenterMoment(self):
+        order = 1
+        moment = CenterMoment(order, dependency='close')
+        tmp_list = []
+        for i, value in enumerate(self.samplesClose):
+            moment.push(dict(close=value))
+            calculated = moment.result()
+            tmp_list.append(value)
+            expected = np.mean(np.power(np.abs(np.array(tmp_list) - np.mean(tmp_list)), order))
+            self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
+                                                             "expected moment:   {1:f}\n"
+                                                             "calculated moment: {2:f}".format(i, expected,
+                                                                                                  calculated))
+        order = 2
+        moment = CenterMoment(order, dependency='close')
+        tmp_list = []
+        for i, value in enumerate(self.samplesClose):
+            moment.push(dict(close=value))
+            calculated = moment.result()
+            tmp_list.append(value)
+            expected = np.mean(np.power(np.abs(np.array(tmp_list) - np.mean(tmp_list)), order))
+            self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
+                                                             "expected moment:   {1:f}\n"
+                                                             "calculated moment: {2:f}".format(i, expected,
+                                                                                                calculated))
+        order = 3
+        moment = CenterMoment(order, dependency='close')
+        tmp_list = []
+        for i, value in enumerate(self.samplesClose):
+            moment.push(dict(close=value))
+            calculated = moment.result()
+            tmp_list.append(value)
+            expected = np.mean(np.power(np.abs(np.array(tmp_list) - np.mean(tmp_list)), order))
+            self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
+                                                             "expected moment:   {1:f}\n"
+                                                             "calculated moment: {2:f}".format(i, expected,
+                                                                                                calculated))
+
+
+    def testSkewness(self):
+        skewness = Skewness(dependency='close')
+        close_list = []
+
+        for i, value in enumerate(self.samplesClose):
+            close_list.append(value)
+            skewness.push(dict(close=value))
+            calculated = skewness.result()
+            this_moment3 = np.mean(np.power(np.abs(np.array(close_list) - np.mean(close_list)), 3))
+            if i == 0:
+                self.assertTrue(np.isnan(calculated))
+            if i >= 1:
+                expected = this_moment3 / np.power(np.std(close_list), 3)
+                self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
+                                                                    "expected skewness:   {1:f}\n"
+                                                                    "calculated skewness: {2:f}".format(i, expected,
+                                                                                                        calculated))
+
+
+    def testKurtosis(self):
+        kurtosis = Kurtosis(dependency='close')
+        close_list = []
+
+        for i, value in enumerate(self.samplesClose):
+            close_list.append(value)
+            kurtosis.push(dict(close=value))
+            calculated = kurtosis.result()
+            this_moment4 = np.mean(np.power(np.abs(np.array(close_list) - np.mean(close_list)), 4))
+            if i == 0:
+                self.assertTrue(np.isnan(calculated))
+            if i >= 1:
+                expected = this_moment4 / np.power(np.std(close_list), 4)
+                self.assertAlmostEqual(expected, calculated, 10, "at index {0:d}\n"
+                                                                    "expected skewness:   {1:f}\n"
+                                                                    "calculated skewness: {2:f}".format(i, expected,
+                                                                                                        calculated))
+
+
+if __name__ == '__main__':
+    unittest.main()
